==> codelink_1.18.0.zip: codelink/doc/CodelinkSet.R <==
###################################################
### chunk number 1: readfile1 eval=FALSE
###################################################
## #line 40 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"
## 
## cset <- readCodelinkSet("targets.txt")
## 


###################################################
### chunk number 2: annotations
###################################################
#line 54 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"

library(codelink)
data(codelink.exprset)
annotation(codelink.exprset)
annotation(codelink.exprset) <- "rwgcod"
annotation(codelink.exprset)



###################################################
### chunk number 3: preprocess
###################################################
#line 83 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"

cset <- codPreprocess(codelink.exprset)



###################################################
### chunk number 4: plot
###################################################
#line 92 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"

codPlot(cset, what = "density")
codPlot(cset, what = "ma")
codPlot(cset, what = "image")



###################################################
### chunk number 5: fit eval=FALSE
###################################################
## #line 107 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"
## 
## design <- model.matrix(~ -1 + factor(cset$Treatment))
## fit <- lmFit(cset, design)
## 


###################################################
### chunk number 6: fit eval=FALSE
###################################################
## #line 118 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"
## 
## writeCodelink(codelink.exprset, file = "intensities.txt")
## 


###################################################
### chunk number 7: fit eval=FALSE
###################################################
## #line 128 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"
## 
## foo.avg <- averageProbes(codelink.exprset)
## 


###################################################
### chunk number 8: sessioninfo
###################################################
#line 139 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpicndJf/R.INSTALL66b439d7/codelink/inst/doc/CodelinkSet.Rnw"

sessionInfo()

==> codelink_1.20.0.zip: codelink/doc/CodelinkSet.R <==
###################################################
### chunk number 1: readfile1 eval=FALSE
###################################################
## #line 40 "CodelinkSet.Rnw"
## 
## cset <- readCodelinkSet("targets.txt")
## 


###################################################
### chunk number 2: annotations
###################################################
#line 54 "CodelinkSet.Rnw"

library(codelink)
data(codelink.exprset)
annotation(codelink.exprset)
annotation(codelink.exprset) <- "rwgcod"
annotation(codelink.exprset)



###################################################
### chunk number 3: preprocess
###################################################
#line 83 "CodelinkSet.Rnw"

cset <- codPreprocess(codelink.exprset)



###################################################
### chunk number 4: plot
###################################################
#line 92 "CodelinkSet.Rnw"

codPlot(cset, what = "density")
codPlot(cset, what = "ma")
codPlot(cset, what = "image")



###################################################
### chunk number 5: fit eval=FALSE
###################################################
## #line 107 "CodelinkSet.Rnw"
## 
## design <- model.matrix(~ -1 + factor(cset$Treatment))
## fit <- lmFit(cset, design)
## 


###################################################
### chunk number 6: fit eval=FALSE
###################################################
## #line 118 "CodelinkSet.Rnw"
## 
## writeCodelink(codelink.exprset, file = "intensities.txt")
## 


###################################################
### chunk number 7: fit eval=FALSE
###################################################
## #line 128 "CodelinkSet.Rnw"
## 
## foo.avg <- averageProbes(codelink.exprset)
## 


###################################################
### chunk number 8: sessioninfo
###################################################
#line 139 "CodelinkSet.Rnw"

sessionInfo()
